pub type EntityHashMap<V> = EntityEquivalentHashMap<Entity, V>;Expand description
A HashMap pre-configured to use EntityHash hashing with an Entity.
Aliased Type
pub struct EntityHashMap<V>(/* private fields */);Trait Implementations
Sourceimpl EntityMapper for EntityHashMap<Entity>
impl EntityMapper for EntityHashMap<Entity>
Sourcefn get_mapped(&mut self, source: Entity) -> Entity
fn get_mapped(&mut self, source: Entity) -> Entity
Returns the corresponding mapped entity or returns entity if there is no mapped entity
Sourcefn set_mapped(&mut self, source: Entity, target: Entity)
fn set_mapped(&mut self, source: Entity, target: Entity)
Maps the
target entity to the given source. For some implementations this might not actually determine the result
of EntityMapper::get_mapped.